@@ -24,7 +24,8 @@ class Application(Resource, DeleteMixin, SaveMixin, StatusMixin):
         'status',
     )
 
-    def get_resource_attributes(self):
+    @staticmethod
+    def get_resource_attributes():
         from .account import AccountList
         from .account_store_mapping import (
             AccountStoreMapping,
