@@ -19,7 +19,8 @@ class GroupMembership(Resource, DeleteMixin):
         'group',
     )
 
-    def get_resource_attributes(self):
+    @staticmethod
+    def get_resource_attributes():
         from .account import Account
         from .group import Group
 
