@@ -11,3 +11,10 @@ class ProviderData(Resource):
     http://docs.stormpath.com/python/product-guide/#integrating-with-google
     http://docs.stormpath.com/python/product-guide/#integrating-with-facebook
     """
+
+    writable_attrs = (
+        'access_token',
+        'code',
+        'provider_id',
+        'refresh_token',
+    )
